/**
* Copyright (C) 2014 EDIT
* European Distributed Institute of Taxonomy
* http://www.e-taxonomy.eu
*
* The contents of this file are subject to the Mozilla Public License Version 1.1
* See LICENSE.TXT at the top of this package for the full license terms.
*/
package eu.etaxonomy.taxeditor.molecular.editor;

import java.util.Arrays;
import java.util.List;
import java.util.UUID;

import eu.etaxonomy.cdm.api.service.molecular.ISequenceService;
import eu.etaxonomy.cdm.model.molecular.Sequence;
import eu.etaxonomy.taxeditor.editor.CdmEntitySessionInput;
import eu.etaxonomy.taxeditor.store.CdmStore;

/**
 * @author pplitzner
 * @author Ben Stöver
 * @date 04.08.2014
 */
public class AlignmentEditorInput extends CdmEntitySessionInput<Sequence> {

    private final UUID sequenceNodeUuid;
    private Sequence sequenceNode;

    public AlignmentEditorInput(UUID sequenceNodeUuid) {
        super(false);
		this.sequenceNodeUuid = sequenceNodeUuid;
		initSession();
	}

	/**
	 * Returns the {@link UUID} of the sequence CDM node that should be edited by the {@link AlignmentEditor} this object
	 * is used with.
	 *
	 * @return the uuid of the CDM node to work on
	 */
	public UUID getSequenceNodeUuid() {
		return sequenceNodeUuid;
	}

	@Override
	public int hashCode() {
		final int prime = 31;
		int result = 1;
		result = prime * result
				+ ((sequenceNodeUuid == null) ? 0 : sequenceNodeUuid.hashCode());
		return result;
	}

	@Override
	public boolean equals(Object obj) {
		if (this == obj) {
            return true;
        }
		if (obj == null) {
            return false;
        }
		if (getClass() != obj.getClass()) {
            return false;
        }
		AlignmentEditorInput other = (AlignmentEditorInput) obj;
		if (sequenceNodeUuid == null) {
			if (other.sequenceNodeUuid != null) {
                return false;
            }
		} else if (!sequenceNodeUuid.equals(other.sequenceNodeUuid)) {
            return false;
        }
		return true;
	}

	public void setSequenceNode(Sequence sequenceNode) {
	    this.sequenceNode = sequenceNode;
	}

	@Override
    public List<Sequence> getRootEntities() {
        return Arrays.asList(sequenceNode);
    }

    @Override
    public void merge() {
        CdmStore.getService(ISequenceService.class).merge(sequenceNode, true);
    }
}
