package eu.etaxonomy.taxeditor.molecular.editor.e4.handler;


import javax.inject.Named;

import org.eclipse.e4.core.di.annotations.CanExecute;
import org.eclipse.e4.core.di.annotations.Execute;
import org.eclipse.e4.ui.model.application.ui.basic.MPart;
import org.eclipse.e4.ui.services.IServiceConstants;

import eu.etaxonomy.taxeditor.molecular.editor.e4.AlignmentEditorE4;
import info.bioinfweb.libralign.alignmentarea.AlignmentArea;



/**
 * Handler that cuts the currently selected nucleotides from an alignment editor to the clipboard.
 * <p>
 * The cut contents either come from the single reads or the consensus sequence alignment area,
 * depending on which component currently has the focus. If none of these components has the focus,
 * nothing will be cut, even if nucleotides are currently selected.
 * <p>
 * If the selection contains parts of multiple sequence, these are separated by the line separator
 * of the current operating system.
 *
 * @author Ben Stöver
 * @date 25.08.2015
 */
public class AlignmentEditorCutHandlerE4 extends AlignmentEditorCopyHandlerE4 {

    @Override
    @Execute
    protected void doExecute2(@Named(IServiceConstants.ACTIVE_PART)MPart activePart) {
        super.doExecute2(activePart);  // Copy selected contents.
        AlignmentEditorE4 editor = (AlignmentEditorE4) activePart.getObject();
        AlignmentArea focusedArea = editor.getFocusedArea();
        focusedArea.getActionProvider().deleteSelection();
    }


    @Override
    @CanExecute
    public boolean isEnabled(@Named(IServiceConstants.ACTIVE_PART)MPart activePart) {
        AlignmentEditorE4 editor = (AlignmentEditorE4) activePart.getObject();
        if (editor != null) {
            AlignmentArea focusedArea = editor.getFocusedArea();
            if (focusedArea != null) {
                return !focusedArea.getSelection().isEmpty();
            }
        }
        return false;
    }

}
