package eu.etaxonomy.taxeditor.molecular.editor.e4.handler;


import javax.inject.Named;

import org.eclipse.e4.core.di.annotations.CanExecute;
import org.eclipse.e4.core.di.annotations.Execute;
import org.eclipse.e4.core.di.annotations.Optional;
import org.eclipse.e4.ui.model.application.MApplication;
import org.eclipse.e4.ui.model.application.ui.basic.MPart;
import org.eclipse.e4.ui.model.application.ui.menu.MHandledMenuItem;
import org.eclipse.e4.ui.services.IServiceConstants;
import org.eclipse.e4.ui.workbench.modeling.EModelService;
import org.eclipse.e4.ui.workbench.modeling.EPartService;
import org.eclipse.jface.viewers.IStructuredSelection;
import org.eclipse.jface.viewers.TreeNode;
import org.eclipse.ui.PartInitException;

import eu.etaxonomy.cdm.model.molecular.Sequence;
import eu.etaxonomy.taxeditor.editor.EditorUtil;
import eu.etaxonomy.taxeditor.molecular.AppModelId;
import eu.etaxonomy.taxeditor.molecular.editor.AlignmentEditorInput;
import eu.etaxonomy.taxeditor.molecular.editor.e4.AlignmentEditorE4;
import eu.etaxonomy.taxeditor.molecular.l10n.Messages;



/**
 * Opens the alignment editor from the CDM tree.
 *
 * @author Ben St&ouml;ver
 * @author pplitzner
 */
public class EditSequenceHandlerE4 {
    private org.apache.log4j.Logger logger = org.apache.log4j.Logger.getLogger(EditSequenceHandlerE4.class);


    @Execute
    public void execute(@Optional@Named(IServiceConstants.ACTIVE_SELECTION)IStructuredSelection selection,
            EPartService partService, EModelService modelService, MApplication application) {
        Sequence sequence = (Sequence) ((TreeNode) selection.getFirstElement()).getValue();
        AlignmentEditorInput input = new AlignmentEditorInput(sequence.getUuid());  //TODO Should there always be a new instance created here? What if the specified CDM node is already opened in an AlignmentEditor? => Possible create Singleton that keeps instances by sequence objects in a map.
        try {
            String partId = AppModelId.PARTDESCRIPTOR_EU_ETAXONOMY_TAXEDITOR_MOLECULAR_EDITOR_E4_ALIGNMENTEDITORE4;
            MPart part = EditorUtil.showPart(partId, modelService, partService, application);
            AlignmentEditorE4 alignmentEditor = (AlignmentEditorE4) part.getObject();
            alignmentEditor.init(input);
        }
        catch (PartInitException e) {
            logger.error(Messages.EditSequenceHandler_COULD_NOT_OPEN, e);
        }
    }

    @CanExecute
    public boolean canExecute(@Optional @Named(IServiceConstants.ACTIVE_SELECTION) IStructuredSelection selection, MHandledMenuItem menuItem) {
        boolean canExecute = false;
        canExecute = selection.size()==1
                && selection.getFirstElement() instanceof TreeNode
                && ((TreeNode) selection.getFirstElement()).getValue() instanceof Sequence;
        menuItem.setVisible(canExecute);
        return canExecute;
    }
}