package eu.etaxonomy.taxeditor.molecular.editor.e4.handler;


import eu.etaxonomy.cdm.common.URI;

import javax.inject.Named;

import org.eclipse.e4.core.di.annotations.CanExecute;
import org.eclipse.e4.core.di.annotations.Execute;
import org.eclipse.e4.core.di.annotations.Optional;
import org.eclipse.e4.ui.model.application.ui.basic.MPart;
import org.eclipse.e4.ui.model.application.ui.menu.MHandledMenuItem;
import org.eclipse.e4.ui.services.IServiceConstants;
import org.eclipse.e4.ui.workbench.modeling.EPartService;
import org.eclipse.e4.ui.workbench.modeling.EPartService.PartState;
import org.eclipse.jface.viewers.IStructuredSelection;
import org.eclipse.jface.viewers.TreeNode;

import eu.etaxonomy.cdm.model.media.MediaUtils;
import eu.etaxonomy.cdm.model.molecular.SingleRead;
import eu.etaxonomy.taxeditor.model.MessagingUtils;
import eu.etaxonomy.taxeditor.molecular.TaxeditorMolecularPlugin;
import eu.etaxonomy.taxeditor.molecular.editor.e4.AlignmentEditorE4;
import eu.etaxonomy.taxeditor.molecular.editor.e4.PherogramPartE4;
import eu.etaxonomy.taxeditor.molecular.l10n.Messages;
import info.bioinfweb.libralign.pherogram.model.PherogramComponentModel;



/**
 * Displays an undistorted pherogram with {@link PherogramPartE4}.
 *
 * @author Ben Stöver
 */
public class ShowPherogramHandlerE4 {

    @Execute
    public void execute(@Optional@Named(IServiceConstants.ACTIVE_SELECTION)IStructuredSelection selection,
            EPartService partService) {
        //TODO Can the parent node (containing the cut positions) be extracted from SingleRead?
        try {
            SingleRead singleRead = (SingleRead) ((TreeNode) selection.getFirstElement()).getValue();
            URI uri = null;
            if (singleRead.getPherogram() != null) {  // Pherogram objects without URI are possible.
                uri = MediaUtils.getFirstMediaRepresentationPart(singleRead.getPherogram()).getUri();
            }

            if (uri == null) {
                MessagingUtils.messageDialog(Messages.ShowPherogramHandler_NO_PHEROGRAM, this,
                        Messages.ShowPherogramHandler_NO_PHEROGRAM_MESSAGE);
            }
            else {
                MPart part = partService.createPart(eu.etaxonomy.taxeditor.molecular.AppModelId.PARTDESCRIPTOR_EU_ETAXONOMY_TAXEDITOR_MOLECULAR_EDITOR_E4_PHEROGRAMPARTE4);
                part = partService.showPart(part, PartState.ACTIVATE);
                PherogramPartE4 pherogramPart = (PherogramPartE4) part.getObject();
                pherogramPart.init(new PherogramComponentModel(AlignmentEditorE4.readPherogram(uri)));
            }
        }
        catch (Exception e) {
            MessagingUtils.errorDialog(Messages.ShowPherogramHandler_ERROR, null, e.getLocalizedMessage(), TaxeditorMolecularPlugin.PLUGIN_ID,
                    e, false);
        }
    }

    @CanExecute
    public boolean canExecute(@Optional @Named(IServiceConstants.ACTIVE_SELECTION) IStructuredSelection selection, MHandledMenuItem menuItem) {
        boolean canExecute = false;
        canExecute = selection.size()==1
                && selection.getFirstElement() instanceof TreeNode
                && ((TreeNode) selection.getFirstElement()).getValue() instanceof SingleRead;
        menuItem.setVisible(canExecute);
        return canExecute;
    }
}
