// $Id$
/**
* Copyright (C) 2016 EDIT
* European Distributed Institute of Taxonomy
* http://www.e-taxonomy.eu
*
* The contents of this file are subject to the Mozilla Public License Version 1.1
* See LICENSE.TXT at the top of this package for the full license terms.
*/
package eu.etaxonomy.taxeditor.molecular.io;

import java.util.Iterator;
import java.util.NoSuchElementException;

import eu.etaxonomy.taxeditor.molecular.l10n.Messages;



/**
 * Iterator implementation used internally be {@link CDMSequenceMatrixAdapter}.
 *
 * @author Ben Stöver
 * @date 29.04.2016
 */
class SequenceIDIterator implements Iterator<String> {
    private boolean containsConsensus;
    private int singleReadPos;
    private int singleReadCount;


    /**
     * Creates a new instance of this class.
     *
     * @param singleReadCount the number of single read IDs to be returned by this iterator before the consensus sequence
     */
    public SequenceIDIterator(int singleReadCount, boolean containsConsensus) {
        super();
        this.containsConsensus = containsConsensus;
        this.singleReadCount = singleReadCount;
        this.singleReadPos = 0;
    }


    @Override
    public boolean hasNext() {
        return (singleReadPos < singleReadCount) || (containsConsensus && (singleReadPos <= singleReadCount));
    }


    @Override
    public String next() {
        if (singleReadPos < singleReadCount) {
            return CDMSequenceMatrixAdapter.SINGLE_READ_SEQUENCE_ID_PREFIX + (singleReadPos++);
        }
        else if (containsConsensus && (singleReadPos == singleReadCount)) {
            singleReadPos++;
            return CDMSequenceMatrixAdapter.CONSENSUS_SEQUENCE_ID;
        }
        else {
            throw new NoSuchElementException(Messages.SequenceIDIterator_NO_MORE_SEQUENCES);
        }
    }


    @Override
    public void remove() {
        throw new UnsupportedOperationException(Messages.SequenceIDIterator_REMOVE_NOT_SUPPORTED);
    }
}
