// $Id$
/**
* Copyright (C) 2016 EDIT
* European Distributed Institute of Taxonomy
* http://www.e-taxonomy.eu
*
* The contents of this file are subject to the Mozilla Public License Version 1.1
* See LICENSE.TXT at the top of this package for the full license terms.
*/
package eu.etaxonomy.taxeditor.molecular.io.wizard;


import java.io.File;

import org.eclipse.core.databinding.DataBindingContext;
import org.eclipse.core.databinding.validation.MultiValidator;
import org.eclipse.core.databinding.validation.ValidationStatus;
import org.eclipse.core.runtime.IStatus;
import org.eclipse.jface.databinding.swt.ISWTObservableValue;
import org.eclipse.jface.databinding.swt.SWTObservables;
import org.eclipse.jface.databinding.wizard.WizardPageSupport;
import org.eclipse.swt.SWT;
import org.eclipse.swt.events.SelectionAdapter;
import org.eclipse.swt.events.SelectionEvent;
import org.eclipse.swt.layout.FormAttachment;
import org.eclipse.swt.layout.FormData;
import org.eclipse.swt.layout.FormLayout;
import org.eclipse.swt.widgets.Button;
import org.eclipse.swt.widgets.Combo;
import org.eclipse.swt.widgets.Composite;
import org.eclipse.swt.widgets.DirectoryDialog;
import org.eclipse.swt.widgets.Label;
import org.eclipse.swt.widgets.Text;

import eu.etaxonomy.taxeditor.molecular.l10n.Messages;
import info.bioinfweb.commons.io.ContentExtensionFileFilter.TestStrategy;
import info.bioinfweb.commons.io.ExtensionFileFilter;
import info.bioinfweb.jphyloio.formatinfo.JPhyloIOFormatInfo;



/**
 * Wizard page that allows to specify which parts of a single read alignment shall be exported to an alignment file.
 *
 * @author Ben St&ouml;ver
 * @date 18.04.2016
 */
public class ExportSingleReadAlignmentFileFormatPage extends AbstractExportSingleReadAlignmentWizardPage {
    private Text fileTextField;
    private Combo formatComboBox;


    /**
     * Create the wizard.
     */
    public ExportSingleReadAlignmentFileFormatPage() {
        super("ExportSingleReadAlignmentFileFormat");  //TODO Which pageName should be used here? Any conventions? //$NON-NLS-1$
        setTitle(Messages.wizardExportAlignmentTitle);
        setDescription(Messages.wizardExportAlignmentDescription);
    }


    /**
     * Create contents of the wizard.
     *
     * @param parent the parent component
     */
    @Override
    public void createControl(Composite parent) {
        DataBindingContext dbc = new DataBindingContext();
        WizardPageSupport.create(this, dbc);

        Composite container = new Composite(parent, SWT.NULL);

        setControl(container);
        container.setLayout(new FormLayout());

        Label lblFormat = new Label(container, SWT.NONE);
        FormData fd_lblFormat = new FormData();
        fd_lblFormat.right = new FormAttachment(100, -10);
        fd_lblFormat.top = new FormAttachment(0, 10);
        fd_lblFormat.left = new FormAttachment(0, 10);
        lblFormat.setLayoutData(fd_lblFormat);
        lblFormat.setText(Messages.wizardExportAlignmentExportFormatLabel);

        Label lblSelectTheExport = new Label(container, SWT.NONE);
        FormData fd_lblSelectTheExport = new FormData();
        fd_lblSelectTheExport.right = new FormAttachment(100, -10);
        fd_lblSelectTheExport.left = new FormAttachment(0, 10);
        lblSelectTheExport.setLayoutData(fd_lblSelectTheExport);
        lblSelectTheExport.setText(Messages.wizardExportAlignmentDestinationLabel);

        Label lblAlignmentFile = new Label(container, SWT.NONE);
        FormData fd_lblAlignmentFile = new FormData();
        fd_lblAlignmentFile.top = new FormAttachment(lblSelectTheExport, 9);
        fd_lblAlignmentFile.right = new FormAttachment(0, 128);
        fd_lblAlignmentFile.left = new FormAttachment(0, 10);
        lblAlignmentFile.setLayoutData(fd_lblAlignmentFile);
        lblAlignmentFile.setText(Messages.wizardExportAlignmentFileLabel);

        fileTextField = new Text(container, SWT.BORDER);
        FormData fd_text = new FormData();
        fd_text.left = new FormAttachment(lblAlignmentFile, 6);
        fd_text.right = new FormAttachment(100, -10);
        fd_text.top = new FormAttachment(lblSelectTheExport, 6);
        fileTextField.setLayoutData(fd_text);
        final ISWTObservableValue fileNameObservable = SWTObservables.observeText(fileTextField, SWT.Modify);
        dbc.bindValue(fileNameObservable, getWizard().getModel().getFileNameObservable());

        Button btnBrowse = new Button(container, SWT.NONE);
        btnBrowse.addSelectionListener(new SelectionAdapter() {
            @Override
            public void widgetSelected(SelectionEvent e) {
                DirectoryDialog dialog = new DirectoryDialog(getShell(), SWT.OPEN);
                dialog.setText(Messages.wizardExportAlignmentFileDialogTitle);
//                ContentExtensionFileFilter filter = getSelectedFormat().createFileFilter(TestStrategy.EXTENSION);
//                dialog.setFilterExtensions(new String[]{filter.getExtensionsAsString()});
//                dialog.setFilterNames(new String[]{filter.getDescription()});
                String selectedFile = dialog.open();
                if (selectedFile != null) {  // Otherwise selecting was canceled.
                    fileTextField.setText(selectedFile+File.separator+fileTextField.getText());
                }
            }
        });
        FormData fd_btnBrowse = new FormData();
        fd_btnBrowse.bottom = new FormAttachment(fileTextField, 43, SWT.BOTTOM);
        fd_btnBrowse.top = new FormAttachment(fileTextField, 13);
        fd_btnBrowse.left = new FormAttachment(100, -128);
        fd_btnBrowse.right = new FormAttachment(100, -10);
        btnBrowse.setLayoutData(fd_btnBrowse);
        btnBrowse.setText(Messages.wizardExportAlignmentBrowseButton);

        formatComboBox = new Combo(container, SWT.READ_ONLY);
        fd_lblSelectTheExport.top = new FormAttachment(formatComboBox, 23);
        for (JPhyloIOFormatInfo formatInfo : ExportSingleReadAlignmentWizardModel.FORMATS) {
            formatComboBox.add(formatInfo.getFormatName());
        }
        FormData fd_formatComboBox = new FormData();
        fd_formatComboBox.top = new FormAttachment(lblFormat, 6);
        fd_formatComboBox.left = new FormAttachment(0, 10);
        fd_formatComboBox.right = new FormAttachment(100, -10);
        formatComboBox.setLayoutData(fd_formatComboBox);
        final ISWTObservableValue formatObservable = SWTObservables.observeSingleSelectionIndex(formatComboBox);  // ViewerProperties.singleSelection().observe(formatComboBox); falls ein ComboViewer verwendet wird. (Dann kann direkt FormatInfo verwendet werden.)
        dbc.bindValue(formatObservable, getWizard().getModel().getFormatInfoObservable());
        formatComboBox.select(0);  // Must happen after the component has been bound to the model.

        Button appendExtensionButton = new Button(container, SWT.NONE);
        appendExtensionButton.addSelectionListener(new SelectionAdapter() {
            @Override
            public void widgetSelected(SelectionEvent e) {
                fileTextField.setText(fileTextField.getText() + ExtensionFileFilter.EXTENSION_SEPARATOR +
                        getSelectedFormat().createFileFilter(TestStrategy.EXTENSION).getDefaultExtension());
            }
        });
        FormData fd_btnNewButton = new FormData();
        fd_btnNewButton.left = new FormAttachment(btnBrowse, -264, SWT.LEFT);
        fd_btnNewButton.bottom = new FormAttachment(fileTextField, 43, SWT.BOTTOM);
        fd_btnNewButton.right = new FormAttachment(btnBrowse, -6);
        fd_btnNewButton.top = new FormAttachment(fileTextField, 13);
        appendExtensionButton.setLayoutData(fd_btnNewButton);
        appendExtensionButton.setText(Messages.wizardExportAlignmentAppendExtensionButton);

        dbc.addValidationStatusProvider(new MultiValidator() {
            @Override
            protected IStatus validate() {
                String fileName = (String)fileNameObservable.getValue();
                Integer index = (Integer)formatObservable.getValue();  // If formatObservable.getValue() is not called from within this method, it is not called on modifications of the according combo anymore. (Would be interesting to know why.)
                if ((fileName == null) || fileName.isEmpty()) {
                    return ValidationStatus.error(Messages.wizardExportAlignmentErrorMissingFileName);
                }
                else if (!ExportSingleReadAlignmentWizardModel.FORMATS.get(index).createFileFilter(TestStrategy.EXTENSION).accept(
                        new File(fileName))) {

                    return ValidationStatus.warning(Messages.wizardExportAlignmentwarningMissingExtension);
                }
                else if (fileName.charAt(0) == ExtensionFileFilter.EXTENSION_SEPARATOR) {
                    return ValidationStatus.warning(Messages.wizardExportAlignmentWarningFileNameStartsDot);
                }
                else if (new File(fileName).exists()) {
                    return ValidationStatus.warning(Messages.wizardExportAlignmentWarningFileExists);
                }
                else {
                    return ValidationStatus.ok();
                }
            }
        });
    }


    private JPhyloIOFormatInfo getSelectedFormat() {
        return ExportSingleReadAlignmentWizardModel.FORMATS.get(formatComboBox.getSelectionIndex());
    }
}
