/**
* Copyright (C) 2016 EDIT
* European Distributed Institute of Taxonomy
* http://www.e-taxonomy.eu
*
* The contents of this file are subject to the Mozilla Public License Version 1.1
* See LICENSE.TXT at the top of this package for the full license terms.
*/
package eu.etaxonomy.taxeditor.molecular.io.wizard;


import info.bioinfweb.commons.bio.SequenceUtils;
import info.bioinfweb.jphyloio.events.type.EventContentType;
import info.bioinfweb.jphyloio.factory.JPhyloIOReaderWriterFactory;
import info.bioinfweb.jphyloio.formatinfo.JPhyloIOFormatInfo;

import java.util.ArrayList;
import java.util.Collections;
import java.util.List;

import org.eclipse.core.databinding.observable.value.IObservableValue;
import org.eclipse.core.databinding.observable.value.WritableValue;



/**
 * The data model for a wizard to export single read alignments to different file formats using <i>JPhyloIO</i>.
 *
 * @author Ben Stöver
 * @date 16.11.2016
 */
public class ExportSingleReadAlignmentWizardModel {
    protected static final JPhyloIOReaderWriterFactory READER_WRITER_FACTORY = new JPhyloIOReaderWriterFactory();
    protected static final List<JPhyloIOFormatInfo> FORMATS = createFormatInfoList();


    private IObservableValue formatInfo = new WritableValue(0, Integer.class);
    private IObservableValue fileName = new WritableValue(null, String.class);
    private IObservableValue exportSingleReads = new WritableValue(true, Boolean.class);
    private IObservableValue exportConsensusSequence = new WritableValue(true, Boolean.class);
    private IObservableValue consensusSequenceLabel = new WritableValue("Consensus", String.class); //$NON-NLS-1$
    private IObservableValue elongateSequences = new WritableValue(false, Boolean.class);
    private IObservableValue useGapToken = new WritableValue(true, Boolean.class);


    private static List<JPhyloIOFormatInfo> createFormatInfoList() {
        List<JPhyloIOFormatInfo> result = new ArrayList<JPhyloIOFormatInfo>();
        for (String formatID : READER_WRITER_FACTORY.getFormatIDsSet()) {
            JPhyloIOFormatInfo info = READER_WRITER_FACTORY.getFormatInfo(formatID);
            if (info.isElementModeled(EventContentType.ALIGNMENT, false)) {  // Check if the current format allows to write alignments.
                result.add(info);
            }
        }
        return Collections.unmodifiableList(result);
    }


    protected IObservableValue getFormatInfoObservable() {
        return formatInfo;
    }


    /**
     * Returns the <i>JPhyloIO</i> format info object to be used for exporting.
     *
     * @return the format info
     */
    public JPhyloIOFormatInfo getFormatInfo() {
        return FORMATS.get((Integer)formatInfo.getValue());
    }


    public String getFileName() {
        return (String)fileName.getValue();
    }


    protected IObservableValue getFileNameObservable() {
        return fileName;
    }


    public boolean isExportSingleReads() {
        return (Boolean)exportSingleReads.getValue();
    }


    protected IObservableValue getExportSingleReadsObservable() {
        return exportSingleReads;
    }


    public boolean isExportConsensusSequence() {
        return (Boolean)exportConsensusSequence.getValue();
    }


    protected IObservableValue getExportConsensusSequenceObservable() {
        return exportConsensusSequence;
    }


    public String getConsensusSequenceLabel() {
        return (String)consensusSequenceLabel.getValue();
    }


    protected IObservableValue getConsensusSequenceLabelObservable() {
        return consensusSequenceLabel;
    }


    public String getElongationToken() {
        if ((Boolean)elongateSequences.getValue()) {
            if ((Boolean)useGapToken.getValue()) {
                return Character.toString(SequenceUtils.GAP_CHAR);
            }
            else {
                return Character.toString(SequenceUtils.MISSING_DATA_CHAR);
            }
        }
        else {
            return null;
        }
    }


    protected IObservableValue getElongateSequencesObservable() {
        return elongateSequences;
    }


    protected IObservableValue getUseGapTokenObservable() {
        return useGapToken;
    }
}
